@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 3677 2010-10-07 07:07:41Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 3695 2010-10-13 05:33:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -19,7 +19,8 @@ require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
 class BaseFrameContainer extends Core
 {
 	protected $_db;	// DB接続オブジェクト
-	const ADMIN_TEMPLATE = '_admin';
+	const ADMIN_TEMPLATE = '_admin';		// 管理画面用テンプレート
+	const SYSTEM_TEMPLATE = '_system';		// システム画面用テンプレート
 	const M_ADMIN_TEMPLATE = 'm/_admin';	// 携帯用管理画面テンプレート
 	const ERR_MESSAGE_ACCESS_DENY = 'Access denied.';		// ウィジェットアクセスエラーのメッセージ
 	const SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
@@ -110,11 +111,10 @@ class BaseFrameContainer extends Core
 			// 非公開URLへは管理権限がないとアクセスできない
 			$canAccess = true;		// アクセス可能かどうか
 			$isErrorAccess = false;		// 不正アクセスかどうか
-			$toAdmin = false;		// 管理画面へ遷移するかどうか
+			$toAdminType = 0;		// 管理画面の遷移タイプ(0=アクセス不可、1=ログイン画面、2=サイト非公開画面)
 			
 			// ページID,ページサブIDからアクセス権をチェック
 			$isPublicUrl = $this->gPage->canAccessUrl();
-			//if (!$isPublicUrl && !$isSystemAdmin){
 			if (!$isPublicUrl && !$isSystemManageUser){// システム運用可能ユーザかどうか
 				$canAccess = false;
 				$isErrorAccess = true;		// 不正アクセスかどうか
@@ -132,7 +132,7 @@ class BaseFrameContainer extends Core
 						($cmd == M3_REQUEST_CMD_CONFIG_WIDGET ||						// ウィジェットの設定
 						$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET)){			// 表示位置を表示するとき(ウィジェット付き)
 						// 管理画面で処理
-						$toAdmin = true;
+						$toAdminType = 1;		// ログイン画面へ
 					}
 				} else {			// _checkAccess()がないときは、標準のアクセス制御
 					// 一般画面へのアクセスを制御
@@ -143,7 +143,7 @@ class BaseFrameContainer extends Core
 
 							// 管理画面で処理
 							$canAccess = false;
-							$toAdmin = true;
+							$toAdminType = 1;		// ログイン画面へ
 						} else if ($cmd != '' &&								// コマンドなし
 							$cmd != M3_REQUEST_CMD_CHANGE_TEMPLATE &&			// テンプレート変更
 							$cmd != M3_REQUEST_CMD_SHOW_POSITION &&				// 表示位置を表示するとき
@@ -158,7 +158,12 @@ class BaseFrameContainer extends Core
 							$isErrorAccess = true;		// 不正アクセス
 						}
 					} else {		// サイトアクセスできない場合は、管理画面でメッセージを表示
-						$toAdmin = true;
+						if ($cmd == M3_REQUEST_CMD_LOGIN ||					// ログイン画面を表示のとき
+							$cmd == M3_REQUEST_CMD_LOGOUT){				// ログアウトのとき
+							$toAdminType = 1;		// ログイン画面へ
+						} else {
+							$toAdminType = 2;		// サイト非公開画面へ
+						}
 						
 						// 不正なコマンドはログを残す
 						if ($cmd != '' &&								// コマンドなし
@@ -179,7 +184,6 @@ class BaseFrameContainer extends Core
 				// システム運用可能ユーザはアクセス可。
 				// ログアウトのときはすでに管理ユーザの可能性があるので、ログアウト時は変更しない
 				if ($isSystemManageUser && $cmd != M3_REQUEST_CMD_LOGOUT) $canAccess = true;
-				//if ($isSystemAdmin) $canAccess = true;		// 管理者はフリーパス
 			}
 			// #################### アクセスログ記録 #######################
 			// DBが使用可能であれば、ログイン処理終了後、アクセスログを残す
@@ -187,13 +191,22 @@ class BaseFrameContainer extends Core
 
 			// アクセス不可のときはここで終了
 			if (!$canAccess){
-				if ($toAdmin){
-					// システム制御モードに変更
-					$this->gPage->setSystemHandleMode(1/*サイト非公開中*/);
-					
-					// システム制御画面を表示
-					$this->_showSystemPage($request);
+				switch ($toAdminType){
+					case 1:			// ログイン画面へ
+						// システム制御モードに変更
+						$this->gPage->setSystemHandleMode(1/*管理画面*/);
+						break;
+					case 2:			// サイト非公開画面へ
+						$this->gPage->setSystemHandleMode(10/*サイト非公開中*/);
+						break;
+					default:		// アクセス不可画面へ
+						// システム制御モードに変更
+						$this->gPage->setSystemHandleMode(11/*アクセス不可*/);
+						break;
 				}
+				// システム制御画面を表示
+				$this->_showSystemPage($request, $toAdminType);
+						
 				// 不正アクセスの場合は、アクセスエラーログを残す
 				if ($isErrorAccess) $this->gOpeLog->writeUserAccess(__METHOD__, '不正なアクセスを検出しました。', 2200, 'アクセスをブロックしました。URL: ' . $this->gEnv->getCurrentRequestUri());
 				return;
@@ -526,7 +539,7 @@ class BaseFrameContainer extends Core
 			//	if ($row['tm_type'] == 1) $convType = 1;		// Joomla!v1.5テンプレートのとき
 			//}
 		}
-	
+
 		// バッファリングの準備
 		if (method_exists($this, '_prepareBuffer')) $this->_prepareBuffer($request);
 	
@@ -767,9 +780,10 @@ class BaseFrameContainer extends Core
 	 * システム制御画面表示
 	 *
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param int $type						画面タイプ(0=アクセス不可、1=ログイン画面、2=サイト非公開画面)
 	 * @return なし
 	 */
-	function _showSystemPage($request)
+	function _showSystemPage($request, $type)
 	{
 		// ページIDを設定
 		$pageId = 'admin_index';		// 管理画面を表示
@@ -780,9 +794,19 @@ class BaseFrameContainer extends Core
 		// DBで設定されている値を取得し、なければ管理用デフォルトテンプレートを使用
 		if ($this->gEnv->getIsMobileSite()){		// 携帯用サイトのアクセスの場合
 			$curTemplateId = self::M_ADMIN_TEMPLATE;	// 携帯管理画面用テンプレート
-		} else {
-			$curTemplateId = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
-			if (empty($curTemplateId)) $curTemplateId = self::ADMIN_TEMPLATE;// 管理用テンプレート
+		} else {			// 携帯以外のサイトへのアクセスの場合
+			if ($type == 1){			// ログインはデフォルトの管理画面テンプレートに固定
+				$curTemplateId = self::ADMIN_TEMPLATE;// 管理用テンプレート
+			} else {
+				$curTemplateId = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
+				if (empty($curTemplateId)){
+					$curTemplateId = self::SYSTEM_TEMPLATE;// システム画面用テンプレート
+				} else {
+					// テンプレートの存在チェック
+					$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplateId . '/index.php';
+					if (!file_exists($templateIndexFile)) $curTemplateId = self::SYSTEM_TEMPLATE;// システム画面用テンプレート
+				}
+			}
 		}
 
 		// 画面を作成
