@@ -18,11 +18,11 @@
 // |          Lorenzo Alberton <l dot alberton at quipo dot it>           |
 // +----------------------------------------------------------------------+
 //
-// $Id: Week.php 2 2007-11-03 04:59:01Z fishbone $
+// $Id: Week.php 2283 2009-09-04 14:46:22Z fishbone $
 //
 /**
  * @package Calendar
- * @version $Id: Week.php 2 2007-11-03 04:59:01Z fishbone $
+ * @version $Id: Week.php 2283 2009-09-04 14:46:22Z fishbone $
  */
 
 /**
@@ -120,7 +120,7 @@ class Calendar_Week extends Calendar
         require_once CALENDAR_ROOT.'Table/Helper.php';
         Calendar::Calendar($y, $m, $d);
         $this->firstDay = $this->defineFirstDayOfWeek($firstDay);
-        $this->tableHelper = & new Calendar_Table_Helper($this, $this->firstDay);
+        $this->tableHelper = new Calendar_Table_Helper($this, $this->firstDay);
         $this->thisWeek = $this->tableHelper->getWeekStart($y, $m, $d, $this->firstDay);
         $this->prevWeek = $this->tableHelper->getWeekStart($y, $m, $d - $this->cE->getDaysInWeek(
             $this->thisYear(),
