@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: messageManager.php 3102 2010-05-07 06:05:36Z fishbone $
+ * @version    SVN: $Id: messageManager.php 3686 2010-10-10 09:48:59Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -27,7 +27,9 @@ class MessageManager extends Core
 	private $langStringLoaded;		// 初期データを読み込んだかどうか
 	private $loadedLang;			// データを読み込んだ言語ID
 	const MSG_SITE_IN_MAINTENANCE = 'msg_site_in_maintenance';			// サイトメンテナンス中メッセージ
+	const MSG_ACCESS_DENY = 'msg_access_deny';							// アクセス不可メッセージ
 	const DEFAULT_MSG_SITE_IN_MAINTENANCE = 'ただいまサイトのメンテナンス中です';// サイトメンテナンス中メッセージのデフォルト値
+	const DEFAULT_MSG_ACCESS_DENY = 'アクセスできません';						// アクセス不可メッセージのデフォルト値
 	
 	/**
 	 * コンストラクタ
@@ -142,6 +144,9 @@ class MessageManager extends Core
 				case self::MSG_SITE_IN_MAINTENANCE:			// サイトメンテナンス中メッセージ
 					$value = self::DEFAULT_MSG_SITE_IN_MAINTENANCE;// サイトメンテナンス中メッセージのデフォルト値
 					break;
+				case self::MSG_ACCESS_DENY:					// アクセス不可メッセージ
+					$value = self::DEFAULT_MSG_ACCESS_DENY;			// アクセス不可メッセージのデフォルト値
+					break;
 				default:
 					$value = '';
 					break;
