@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: update_widgets.sql 3715 2010-10-19 04:27:12Z fishbone $
+-- * @version    SVN: $Id: update_widgets.sql 3730 2010-10-24 15:13:05Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -340,7 +340,7 @@ INSERT INTO _widgets
 DELETE FROM _widgets WHERE wd_id = 'm/pc_content';
 INSERT INTO _widgets
 (wd_id,      wd_name,          wd_type, wd_version, wd_params, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_device_type, wd_mobile, wd_has_admin, wd_initialized, wd_install_dt, wd_create_dt) VALUES
-('m/pc_content', 'PC共通コンテンツ', 'content',  '1.0.0',    '',        'Naoki Hirata', 'Magic3.org', 'GPL',      10, 'PC共通コンテンツ表示。', 1,              true,      true,         true,              now(),         now());
+('m/pc_content', 'PC共通コンテンツ', 'content',  '2.0.0',    '',        'Naoki Hirata', 'Magic3.org', 'GPL',      10, 'PCの汎用コンテンツを自動的に携帯用に変換して表示。', 1,              true,      true,         true,              now(),         now());
 DELETE FROM _widgets WHERE wd_id = 'm/content_search_box';
 INSERT INTO _widgets
 (wd_id,                  wd_name,              wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_device_type,         wd_mobile, wd_has_admin, wd_initialized, wd_install_dt, wd_create_dt) VALUES
@@ -385,6 +385,10 @@ DELETE FROM _widgets WHERE wd_id = 'm/separator';
 INSERT INTO _widgets
 (wd_id,         wd_name,      wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description,               wd_mobile, wd_has_admin, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
 ('m/separator', 'セパレータ', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'ウィジェット間の区切り線。', true,      false,        true,          0, 1, -1, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'm/g_analytics';
+INSERT INTO _widgets
+(wd_id,         wd_name,            wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_device_type, wd_mobile, wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
+('m/g_analytics', 'Google Analytics', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'Google Analytics トラッキングコードを出力する。', 1, true, true,        true,           1, -1, now(), now());
 
 -- ウィジェット情報(スマートフォン用)
 DELETE FROM _widgets WHERE wd_id = 's/content';
@@ -399,6 +403,10 @@ DELETE FROM _widgets WHERE wd_id = 's/custom_footer';
 INSERT INTO _widgets
 (wd_id,             wd_name,          wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description,                             wd_device_type, wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
 ('s/custom_footer', 'カスタムフッタ', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'フッタ部に表示し、著作権等の表示を行う。', 2,              true,         true,             1, -1,  now(),         now());
+DELETE FROM _widgets WHERE wd_id = 's/g_analytics';
+INSERT INTO _widgets
+(wd_id,         wd_name,            wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_device_type, wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
+('s/g_analytics', 'Google Analytics', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'Google Analytics トラッキングコードを出力する。', 2, true,        true,           1, -1, now(), now());
 
 -- ウィジェット情報(サーバ連携用)
 DELETE FROM _widgets WHERE wd_id = 'c/updateinfo';
