@@ -7,9 +7,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: fckconfig.js 3332 2010-07-03 02:12:12Z fishbone $
+ * @version    SVN: $Id: fckconfig.js 3726 2010-10-24 09:15:09Z fishbone $
  * @link       http://www.magic3.org
  */
+FCKConfig.EnterMode = 'div' ;			// p | div | br
+FCKConfig.ShiftEnterMode = 'br' ;	// p | div | br
+
 FCKConfig.LinkBrowser = false ;
 FCKConfig.LinkDlgHideTarget		= false ;
 FCKConfig.LinkDlgHideAdvanced	= true ;
